@@ -3,15 +3,13 @@
 import json
 import requests
 import pandas as pd
-import pytz
-from timezonefinder import TimezoneFinder
 
 
 URL = 'https://api.oikolab.com/weather'
 DEFAULT_VARS = [
     'temperature',
     'wind_speed',
-    'wind_gust',
+    '10m_wind_gust',
     'wind_direction',
     'total_precipitation',
     'surface_pressure',
@@ -25,16 +23,6 @@ def format_date(date):
     return date
 
 
-def get_offset(lat, lon):
-    """Convert hour to UTC"""
-    tf = TimezoneFinder()
-    tz = tf.timezone_at(lng=lon, lat=lat)
-    sample_date = pd.to_datetime('2021-01-01')
-    utcoffset = pytz.timezone(tz).utcoffset(sample_date)
-    dstoffset = pytz.timezone(tz).dst(sample_date)
-    return utcoffset - dstoffset
-
-
 def get_oikolab(lat, lon, start, end, api_key, variables, freq):
     """Download hourly weather data from oikolab"""
     if not variables:
@@ -62,8 +50,6 @@ def get_oikolab(lat, lon, start, end, api_key, variables, freq):
         'wind_direction (deg)': 'wind_direction',
         'wind_speed (m/s)': 'wind_speed'
     })
-    offset = get_offset(lat, lon)
-    utc = df.index.map(lambda x: x - offset)
-    df['date'] = utc.map(lambda x: x.strftime('%Y%m%d'))
-    df['hour'] = utc.map(lambda x: x.strftime('%H'))
+    df['date'] = df.index.map(lambda x: x.strftime('%Y%m%d'))
+    df['hour'] = df.index.map(lambda x: x.strftime('%H'))
     return df
